Function caesar::main

source ·
pub(crate) fn main() -> Result<(), Box<dyn Error + Send + Sync>>
Entry point of the application.

This function is called when the application is started. It initializes the environment, parses the command line arguments, and runs the application.